@@ -9,7 +9,7 @@ from trytond.tools import get_smtp_server
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 
-__all__ = ['Event', 'Attendee', 'EventAttendee']
+__all__ = ['Event', 'EventAttendee']
 __metaclass__ = PoolMeta
 
 
@@ -176,10 +176,10 @@ class Event:
                     value = getattr(self, field)
                 if lang.direction == 'ltr':
                     body += fields[field]['string'] + separator + ' ' \
-                            + value + '\n'
+                        + value + '\n'
                 else:
                     body += value + ' ' + separator \
-                            + fields[field]['string'] + '\n'
+                        + fields[field]['string'] + '\n'
         return subject, body
 
     @staticmethod
@@ -275,71 +275,71 @@ class Event:
         return to_notify, owner
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
         Attendee = Pool().get('calendar.event.attendee')
-        event = super(Event, cls).create(values)
+        events = super(Event, cls).create(vlist)
 
         if Transaction().user == 0:
             # user is 0 means create is triggered by another one
-            return event
+            return events
 
-        to_notify, owner = event.attendees_to_notify()
-        if not to_notify:
-            return event
+        for event in events:
+            to_notify, owner = event.attendees_to_notify()
+            if not to_notify:
+                continue
 
-        with Transaction().set_context(skip_schedule_agent=True):
-            ical = event.event2ical()
-        ical.add('method')
-        ical.method.value = 'REQUEST'
+            with Transaction().set_context(skip_schedule_agent=True):
+                ical = event.event2ical()
+            ical.add('method')
+            ical.method.value = 'REQUEST'
 
-        attendee_emails = [a.email for a in to_notify]
+            attendee_emails = [a.email for a in to_notify]
 
-        subject, body = event.subject_body('new', owner)
-        msg = cls.create_msg(owner.email, attendee_emails, subject, body, ical)
-        sent = event.send_msg(owner.email, attendee_emails, msg, 'new')
+            subject, body = event.subject_body('new', owner)
+            msg = cls.create_msg(owner.email, attendee_emails, subject, body,
+                ical)
+            sent = event.send_msg(owner.email, attendee_emails, msg, 'new')
 
-        vals = {'status': 'needs-action'}
-        if sent:
-            vals['schedule_status'] = '1.1'  # successfully sent
-        else:
-            vals['schedule_status'] = '5.1'  # could not complete delivery
-        Attendee.write(to_notify, vals)
+            vals = {'status': 'needs-action'}
+            if sent:
+                vals['schedule_status'] = '1.1'  # successfully sent
+            else:
+                vals['schedule_status'] = '5.1'  # could not complete delivery
+            Attendee.write(to_notify, vals)
 
-        return event
+        return events
 
     @classmethod
-    def write(cls, events, values):
+    def write(cls, *args):
         Attendee = Pool().get('calendar.event.attendee')
 
         if Transaction().user == 0:
             # user is 0 means write is triggered by another one
-            super(Event, cls).write(events, values)
+            super(Event, cls).write(*args)
             return
 
-        if not values or not events:
-            super(Event, cls).write(events, values)
-            return
+        actions = iter(args)
+        for events, values in zip(actions, actions):
+            event_edited = False
+            for k in values:
+                if k != 'attendees':
+                    event_edited = True
+                    break
 
-        event_edited = False
-        for k in values:
-            if k != 'attendees':
-                event_edited = True
-                break
+            # store old attendee info
+            event2former_emails = {}
+            former_organiser_mail = {}
+            former_organiser_lang = {}
+            for event in events:
+                to_notify, owner = event.attendees_to_notify()
+                event2former_emails[event.id] = [a.email for a in to_notify]
+                former_organiser_mail[event.id] = owner and owner.email
+                former_organiser_lang[event.id] = owner and owner.language \
+                    and owner.language.code
 
-        # store old attendee info
-        event2former_emails = {}
-        former_organiser_mail = {}
-        former_organiser_lang = {}
-        for event in events:
-            to_notify, owner = event.attendees_to_notify()
-            event2former_emails[event.id] = [a.email for a in to_notify]
-            former_organiser_mail[event.id] = owner and owner.email
-            former_organiser_lang[event.id] = owner and owner.language \
-                and owner.language.code
+        super(Event, cls).write(*args)
 
-        super(Event, cls).write(events, values)
-
-        for event in events:
+        for event in sum(args[::2], []):
             current_attendees, owner = event.attendees_to_notify()
             owner_email = owner and owner.email
             current_emails = [a.email for a in current_attendees]
@@ -468,8 +468,7 @@ class Event:
             event.send_msg(owner_email, attendee_emails, msg, 'cancel')
 
 
-class Attendee:
-    __name__ = 'calendar.attendee'
+class AttendeeMixin:
     schedule_status = fields.Selection([
             ('', ''),
             ('1.0', '1.0'),
@@ -494,7 +493,7 @@ class Attendee:
 
     @classmethod
     def attendee2values(cls, attendee):
-        values = super(Attendee, cls).attendee2values(attendee)
+        values = super(AttendeeMixin, cls).attendee2values(attendee)
         if hasattr(attendee, 'schedule_status'):
             if attendee.schedule_status in dict(
                     cls.schedule_status.selection):
@@ -505,7 +504,7 @@ class Attendee:
         return values
 
     def attendee2attendee(self):
-        attendee = super(Attendee, self).attendee2attendee()
+        attendee = super(AttendeeMixin, self).attendee2attendee()
 
         if self.schedule_status:
             if hasattr(attendee, 'schedule_status_param'):
@@ -537,7 +536,8 @@ class Attendee:
         return attendee
 
 
-class EventAttendee:
+class EventAttendee(AttendeeMixin, object):
+    __metaclass__ = PoolMeta
     __name__ = 'calendar.event.attendee'
 
     @classmethod
@@ -595,7 +595,7 @@ class EventAttendee:
         fields_names = ['status']
         with Transaction().set_context(language=lang.code):
             fields = self.fields_get(fields_names=fields_names)
-        for k, v in  fields['status']['selection']:
+        for k, v in fields['status']['selection']:
             if k == status:
                 status_string = v
 
@@ -645,10 +645,10 @@ class EventAttendee:
                     value = event[field]
                 if lang.direction == 'ltr':
                     body += fields[field]['string'] + separator + ' ' \
-                            + value + '\n'
+                        + value + '\n'
                 else:
                     body += value + ' ' + separator \
-                            + fields[field]['string'] + '\n'
+                        + fields[field]['string'] + '\n'
         return subject, body
 
     @staticmethod
@@ -716,25 +716,26 @@ class EventAttendee:
         return organizer
 
     @classmethod
-    def write(cls, attendees, values):
+    def write(cls, *args):
         Event = Pool().get('calendar.event')
 
         if Transaction().user == 0:
             # user is 0 means write is triggered by another one
-            super(EventAttendee, cls).write(attendees, values)
-            return
-
-        if 'status' not in values:
-            super(EventAttendee, cls).write(attendees, values)
+            super(EventAttendee, cls).write(*args)
             return
 
+        actions = iter(args)
+        status_attendees = []
         att2status = {}
-        for attendee in attendees:
-            att2status[attendee.id] = attendee.status
+        for attendees, values in zip(actions, actions):
+            if 'status' in values:
+                status_attendees += attendees
+                for attendee in attendees:
+                    att2status[attendee.id] = attendee.status
 
-        super(EventAttendee, cls).write(attendees, values)
+        super(EventAttendee, cls).write(*args)
 
-        for attendee in attendees:
+        for attendee in status_attendees:
             owner = attendee.event.calendar.owner
             if not owner or not owner.calendar_email_notification_partstat:
                 continue
@@ -802,36 +803,38 @@ class EventAttendee:
             Event.write([attendee.event], vals)
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
         Event = Pool().get('calendar.event')
 
-        attendee = super(EventAttendee, cls).create(values)
+        attendees = super(EventAttendee, cls).create(vlist)
         if Transaction().user == 0:
             # user is 0 means create is triggered by another one
-            return attendee
+            return attendees
 
-        owner = attendee.event.calendar.owner
+        for attendee in attendees:
+            owner = attendee.event.calendar.owner
 
-        if (not attendee.status) or attendee.status in ('', 'needs-action'):
-            return attendee
-        if not owner or not owner.calendar_email_notification_partstat:
-            return attendee
-        organizer = attendee.organiser_to_notify()
-        if not organizer:
-            return attendee
+            if ((not attendee.status)
+                    or attendee.status in ('', 'needs-action')):
+                continue
+            if not owner or not owner.calendar_email_notification_partstat:
+                continue
+            organizer = attendee.organiser_to_notify()
+            if not organizer:
+                continue
 
-        with Transaction().set_context(skip_schedule_agent=True):
-            ical = attendee.event.event2ical()
-        if not hasattr(ical, 'method'):
-            ical.add('method')
-        ical.method.value = 'REPLY'
+            with Transaction().set_context(skip_schedule_agent=True):
+                ical = attendee.event.event2ical()
+            if not hasattr(ical, 'method'):
+                ical.add('method')
+            ical.method.value = 'REPLY'
 
-        subject, body = attendee.subject_body(attendee.status, owner)
-        msg = cls.create_msg(owner.email, organizer, subject, body, ical)
+            subject, body = attendee.subject_body(attendee.status, owner)
+            msg = cls.create_msg(owner.email, organizer, subject, body, ical)
 
-        sent = attendee.send_msg(owner.email, organizer, msg)
+            sent = attendee.send_msg(owner.email, organizer, msg)
 
-        vals = {'organizer_schedule_status': sent and '1.1' or '5.1'}
-        Event.write([attendee.event], vals)
+            vals = {'organizer_schedule_status': sent and '1.1' or '5.1'}
+            Event.write([attendee.event], vals)
 
-        return attendee
+        return attendees
